@@ -17,12 +17,12 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {statistics} @var{p} = anova1 (@var{x})
-## @deftypefnx {statistics} @var{p} = anova1 (@var{x}, @var{group})
-## @deftypefnx {statistics} @var{p} = anova1 (@var{x}, @var{group}, @var{displayopt})
-## @deftypefnx {statistics} @var{p} = anova1 (@var{x}, @var{group}, @var{displayopt}, @var{vartype})
-## @deftypefnx {statistics} [@var{p}, @var{atab}] = anova1 (@var{x}, @dots{})
-## @deftypefnx {statistics} [@var{p}, @var{atab}, @var{stats}] = anova1 (@var{x}, @dots{})
+## @deftypefn  {statistics} {@var{p} =} anova1 (@var{x})
+## @deftypefnx {statistics} {@var{p} =} anova1 (@var{x}, @var{group})
+## @deftypefnx {statistics} {@var{p} =} anova1 (@var{x}, @var{group}, @var{displayopt})
+## @deftypefnx {statistics} {@var{p} =} anova1 (@var{x}, @var{group}, @var{displayopt}, @var{vartype})
+## @deftypefnx {statistics} {[@var{p}, @var{atab}] =} anova1 (@var{x}, @dots{})
+## @deftypefnx {statistics} {[@var{p}, @var{atab}, @var{stats}] =} anova1 (@var{x}, @dots{})
 ##
 ## Perform a one-way analysis of variance (ANOVA) for comparing the means of two
 ## or more groups of data under the null hypothesis that the groups are drawn
@@ -281,16 +281,19 @@ endfunction
 
 %!demo
 %! x = meshgrid (1:6);
+%! randn ("seed", 15);    # for reproducibility
 %! x = x + normrnd (0, 1, 6, 6);
 %! anova1 (x, [], 'off');
 
 %!demo
 %! x = meshgrid (1:6);
+%! randn ("seed", 15);    # for reproducibility
 %! x = x + normrnd (0, 1, 6, 6);
 %! [p, atab] = anova1(x);
 
 %!demo
 %! x = ones (50, 4) .* [-2, 0, 1, 5];
+%! randn ("seed", 13);    # for reproducibility
 %! x = x + normrnd (0, 2, 50, 4);
 %! groups = {"A", "B", "C", "D"};
 %! anova1 (x, groups);
