@@ -1,5 +1,5 @@
 ## Copyright (C) 2022-2023 Andreas Bertsatos <abertsatos@biol.uoa.gr>
-## Copyright (C) 2023 Nick Jankowski
+## Copyright (C) 2023 Nicholas Jankowski <jankowski.nicholas@gmail.com>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -17,24 +17,20 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {statistics} @var{m} = median (@var{x})
-## @deftypefnx {statistics} @var{m} = median (@var{x}, "all")
-## @deftypefnx {statistics} @var{m} = median (@var{x}, @var{dim})
-## @deftypefnx {statistics} @var{m} = median (@var{x}, @var{vecdim})
-## @deftypefnx {statistics} @var{m} = median (@dots{}, @var{outtype})
-## @deftypefnx {statistics} @var{m} = median (@dots{}, @var{nanflag})
+## @deftypefn  {statistics} {@var{m} =} median (@var{x})
+## @deftypefnx {statistics} {@var{m} =} median (@var{x}, "all")
+## @deftypefnx {statistics} {@var{m} =} median (@var{x}, @var{dim})
+## @deftypefnx {statistics} {@var{m} =} median (@var{x}, @var{vecdim})
+## @deftypefnx {statistics} {@var{m} =} median (@dots{}, @var{outtype})
+## @deftypefnx {statistics} {@var{m} =} median (@dots{}, @var{nanflag})
 ##
 ## Compute the median value of the elements of @var{x}.
 ##
 ## When the elements of @var{x} are sorted, say
 ## @code{@var{s} = sort (@var{x})}, the median is defined as
 ## @tex
-## $$
-## {\rm median} (x) =
-##   \cases{s(\lceil N/2\rceil), & $N$ odd;\cr
-##           (s(N/2)+s(N/2+1))/2, & $N$ even.}
-## $$
-## where $N$ is the number of elements of @var{x}.
+## $$ {\rm median} (x) = \cases{s(\lceil N/2\rceil), & $N$ odd;
+##                       \cr (s(N/2)+s(N/2+1))/2, & $N$ even.} $$
 ##
 ## @end tex
 ## @ifnottex
@@ -48,19 +44,16 @@
 ## @end example
 ##
 ## @end ifnottex
-## @itemize
-## @item
-## If @var{x} is a matrix, then @code{median (@var{x})} returns a row vector
-## with the mean of each column in @var{x}.
+## @noindent
+## where @math{N} is the number of elements of @var{x}.
 ##
-## @item
-## If @var{x} is a multidimensional array, then @code{median (@var{x})}
-## operates along the first non-singleton dimension of @var{x}.
-## @end itemize
+## If @var{x} is an array, then @code{median (@var{x})} operates along the first
+## non-singleton dimension of @var{x}.
 ##
-## @code{median (@var{x}, @var{dim})} returns the median along the operating
-## dimension @var{dim} of @var{x}.  For @var{dim} greater than
-## @code{ndims (@var{x})}, then @var{m} = @var{x}.
+## The optional variable @var{dim} forces @code{median} to operate over the
+## specified dimension, which must be a positive integer-valued number.
+## Specifying any singleton dimension in @var{x}, including any dimension
+## exceeding @code{ndims (@var{x})}, will result in a median equal to @var{x}.
 ##
 ## @code{median (@var{x}, @var{vecdim})} returns the median over the
 ## dimensions specified in the vector @var{vecdim}.  For example, if @var{x}
@@ -79,25 +72,27 @@
 ## data type, using any of the input arguments in the previous syntaxes.
 ## @var{outtype} can take the following values:
 ## @itemize
-## @item "default"
-## Output is of type double, unless the input is single in which case the output
-## is of type single.
+## @item @qcode{"default"}
+## Output is of type double, unless the input is single in which case the
+## output is of type single.
 ##
-## @item "double"
+## @item @qcode{"double"}
 ## Output is of type double.
 ##
-## @item "native".
+## @item @qcode{"native"}
 ## Output is of the same type as the input (@code{class (@var{x})}), unless the
 ## input is logical in which case the output is of type double.
 ## @end itemize
 ##
-## @code{median (@dots{}, @var{nanflag})} specifies whether to exclude NaN
-## values from the calculation, using any of the input argument combinations in
-## previous syntaxes.  By default, NaN values are included in the calculation
-## (@var{nanflag} has the value "includenan").  To exclude NaN values, set the
-## value of @var{nanflag} to "omitnan".
+## The optional variable @var{nanflag} specifies whether to include or exclude
+## NaN values from the calculation using any of the previously specified input
+## argument combinations.  The default value for @var{nanflag} is
+## @qcode{"includenan"} which keeps NaN values in the calculation.  To
+## exclude NaN values set the value of @var{nanflag} to @qcode{"omitnan"}.
+## The output will still contain NaN values if @var{x} consists of all NaN
+## values in the operating dimension.
 ##
-## @seealso{mean, mode}
+## @seealso{mean, mad, mode}
 ## @end deftypefn
 
 function m = median (x, varargin)
@@ -111,12 +106,12 @@ function m = median (x, varargin)
   endif
 
   ## Set initial conditions
-  all_flag = 0;
-  omitnan = 0;
-  perm_flag = 0;
-  out_flag = 0;
-  vecdim_flag = 0;
-  dim = [];
+  all_flag    = false;
+  omitnan     = false;
+  perm_flag   = false;
+  out_flag    = false;
+  vecdim_flag = false;
+  dim         = [];
 
   nvarg = numel (varargin);
   varg_chars = cellfun ("ischar", varargin);
@@ -131,16 +126,16 @@ function m = median (x, varargin)
 
   ## Process any other char arguments.
   if (any (varg_chars))
-    for idx = varargin(varg_chars)
-      switch (tolower (idx{:}))
+    for argin = varargin(varg_chars)
+      switch (tolower (argin{:}))
         case "all"
-          all_flag = 1;
+          all_flag = true;
 
         case "omitnan"
-          omitnan = 1;
+          omitnan = true;
 
         case "includenan"
-          omitnan = 1;
+          omitnan = false;
 
         case "native"
           if (out_flag)
@@ -149,7 +144,7 @@ function m = median (x, varargin)
           if (strcmp (outtype, "logical"))
             outtype = "double";
           endif
-          out_flag = 1;
+          out_flag = true;
 
         case "default"
           if (out_flag)
@@ -158,14 +153,14 @@ function m = median (x, varargin)
           if (! strcmp (outtype, "single"))
             outtype = "double";
           endif
-          out_flag = 1;
+          out_flag = true;
 
         case "double"
           if (out_flag)
             error ("median: only one OUTTYPE can be specified.")
           endif
           outtype = "double";
-          out_flag = 1;
+          out_flag = true;
 
         otherwise
           print_usage ();
@@ -176,8 +171,8 @@ function m = median (x, varargin)
     nvarg = numel (varargin);
   endif
 
-  if (((nvarg == 1) && ! (isnumeric (varargin{1}))) || (nvarg > 1))
-    ## After trimming char inputs can only be one varargin left, must be numeric
+  if ((nvarg == 1 && ! isnumeric (varargin{1})) || nvarg > 1)
+    ## After trimming char inputs should only be one numeric varargin left
     print_usage ();
   endif
 
@@ -191,7 +186,7 @@ function m = median (x, varargin)
     dim = varargin{1};
     vecdim_flag = ! isscalar (dim);
 
-    if (! (isvector (dim) && (dim > 0)) || any (rem (dim, 1)))
+    if (! (isvector (dim) && dim > 0) || any (rem (dim, 1)))
       error ("median: DIM must be a positive integer scalar or vector.");
     endif
 
@@ -214,13 +209,13 @@ function m = median (x, varargin)
       if (isempty (dim))
         ## No dims left to process, return input as output
         if (! strcmp (class (x), outtype))
-          m = outtype_convert (x, outtype);
+          m = feval (outtype, x);  # convert to outtype
         else
           m = x;
         endif
         return;
-      elseif ((length(dim) == length(sing_dim_x)) ...
-                 && unique ([dim, sing_dim_x]) == dim)
+      elseif (numel (dim) == numel (sing_dim_x)
+              && unique ([dim, sing_dim_x]) == dim)
         ## If DIMs cover all nonsingleton ndims(x) it's equivalent to "all"
         ##   (check lengths first to reduce unique overhead if not covered)
         all_flag = true;
@@ -228,9 +223,9 @@ function m = median (x, varargin)
     endif
 
   else
-    ## Dim not provided.  Determine scalar dimension
+    ## Dim not provided.  Determine scalar dimension.
     if (all_flag)
-      ## Special case 'all': Recast input as dim1 vector, process as normal
+      ## Special case 'all': Recast input as dim1 vector, process as normal.
       x = x(:);
       szx = [length(x), 1];
       dim = 1;
@@ -241,9 +236,8 @@ function m = median (x, varargin)
       dim = 2;
       sz_out = [1, 1];
 
-    elseif (isempty (x) && isequal (szx, [0, 0]))
-      ## Special case []: Do not apply sz_out(dim)=1 change
-      ##   (check isempty first to reduce overhead on non-emptys)
+    elseif (ndx == 2 && szx == [0, 0])
+      ## Special case []: Do not apply sz_out(dim)=1 change.
       dim = 1;
       sz_out = [1, 1];
 
@@ -267,10 +261,16 @@ function m = median (x, varargin)
     return;
   endif
 
+   if (all (isnan (x)(:)))
+    ## all NaN input, output single or double NaNs in pre-determined size
+    m = NaN(sz_out, outtype);
+    return
+  endif
+
   if (szx(dim) == 1)
     ## Operation along singleton dimension - nothing to do
     if (! strcmp (class (x), outtype))
-      m = outtype_convert (x, outtype);
+      m = feval (outtype, x);  # convert to outtype
     else
       m = x;
     endif
@@ -278,27 +278,26 @@ function m = median (x, varargin)
   endif
 
   ## Permute dim to simplify all operations along dim1.  At func. end ipermute.
-  if ((length (dim) > 1) || (dim != 1 && ! isvector (x)))
-    perm_vect = 1 : ndx;
+  if (numel (dim) > 1 || (dim != 1 && ! isvector (x)))
+    perm = 1 : ndx;
 
     if (! vecdim_flag)
       ## Move dim to dim 1
-      perm_vect([1, dim]) = [dim, 1];
-      x = permute (x, perm_vect);
+      perm([1, dim]) = [dim, 1];
+      x = permute (x, perm);
       szx([1, dim]) = szx([dim, 1]);
       dim = 1;
 
     else
       ## Move vecdims to front
-      perm_vect(dim) = [];
-      perm_vect = [dim, perm_vect];
-      x = permute (x, perm_vect);
+      perm(dim) = [];
+      perm = [dim, perm];
+      x = permute (x, perm);
 
       ## Reshape all vecdims into dim1
       num_dim = prod (szx(dim));
       szx(dim) = [];
-      szx = [ones(1, length(dim)), szx];
-      szx(1) = prod (num_dim);
+      szx = [num_dim, ones(1, numel(dim)-1), szx];
       x = reshape (x, szx);
       dim = 1;
     endif
@@ -307,16 +306,17 @@ function m = median (x, varargin)
   endif
 
   ## Find column locations of NaNs
-  hasnan = any (isnan (x), dim);
-  if (! hasnan(:) && omitnan)
-    ## Don't use omitnan path if no NaNs are present
-    omitnan = 0;
+  nanfree = ! any (isnan (x), dim);
+  if (omitnan && nanfree(:))
+    ## Don't use omitnan path if no NaNs are present.  Prevents any data types
+    ## without a defined NaN from following the omitnan codepath.
+    omitnan = false;
   endif
 
-  x = sort (x, dim); # Note- pushes any NaN's to end
+  x = sort (x, dim); # Note: pushes any NaN's to end for omitnan compatibility
 
   if (omitnan)
-    ## Ignore any NaN's in data. Each operating vector might have a
+    ## Ignore any NaN's in data.  Each operating vector might have a
     ## different number of non-NaN data points.
 
     if (isvector (x))
@@ -333,10 +333,14 @@ function m = median (x, varargin)
       endif
 
     else
-      n = sum (! isnan (x), 1);
-      k = floor ((n + 1) ./ 2);
+      ## Each column may have a different n and k.  Force index column vector
+      ## for consistent orientation for 2D and nD inputs, then use sub2ind to
+      ## get correct element(s) for each column.
+
+      n = sum (! isnan (x), 1)(:);
+      k = floor ((n + 1) / 2);
       m_idx_odd = mod (n, 2) & n;
-      m_idx_even = ! m_idx_odd & n;
+      m_idx_even = (! m_idx_odd) & n;
 
       m = NaN ([1, szx(2 : end)]);
 
@@ -345,75 +349,96 @@ function m = median (x, varargin)
       endif
 
       ## Grab kth value, k possibly different for each column
-      x_idx_odd = sub2ind (szx, (k(m_idx_odd))(:)', ...
-                             (1 : szx(2))(m_idx_odd)(:)');
-      x_idx_even = sub2ind (szx, ...
-                             [(k(m_idx_even))(:)'; (k(m_idx_even) + 1)(:)'], ...
-                               (1 : szx(2))(m_idx_even)([1 1], :));
-
-      m(m_idx_odd) = x(x_idx_odd);
-      m(m_idx_even) = sum (x(x_idx_even), 1) / 2;
+      if (any (m_idx_odd))
+        x_idx_odd = sub2ind (szx, k(m_idx_odd), find (m_idx_odd));
+        m(m_idx_odd) = x(x_idx_odd);
+      endif
+      if (any (m_idx_even))
+        k_even = k(m_idx_even);
+        x_idx_even = sub2ind (szx, [k_even, k_even+1], ...
+                                (find (m_idx_even))(:,[1 1]));
+        m(m_idx_even) = sum (x(x_idx_even), 2) / 2;
+      endif
     endif
 
   else
-    ## No "omitnan". All 'vectors' uniform length.
-    if (! all (hasnan))
+    ## No "omitnan".  All 'vectors' uniform length.
+    ## All types without a NaN value will use this path.
+    if (all (!nanfree))
+      m = NaN (sz_out);
 
+    else
       if (isvector (x))
         n = length (x);
         k = floor ((n + 1) / 2);
-        if (mod (n, 2))
-          ## Odd
-          m = x(k);
-        else
+
+        m = x(k);
+        if (! mod (n, 2))
           ## Even
-          m = (x(k) + x(k + 1)) / 2;
+          if (any (isinf ([x(k), x(k+1)])))
+            ## If either center value is Inf, replace m by +/-Inf or NaN.
+            m = x(k) + x(k+1);
+          elseif (any (isa (x, "integer")))
+            ## avoid int overflow issues
+            m2 = x(k+1);
+            if (sign(m) != sign(m2))
+              m += m2;
+              m /= 2;
+            else
+              m += (m2 - m) / 2;
+            endif
+          else
+            m += (x(k+1) - m) / 2;
+          endif
         endif
 
       else
-        ## Nonvector, all operations permuted to be along dim 1
+        ## Nonvector, all operations were permuted to be along dim 1
         n = szx(1);
         k = floor ((n + 1) / 2);
-        m = NaN ([1, szx(2 : end)]);
-        if (mod (n, 2))
-          ## Odd
-          m(1, :) = x(k, :);
+
+        if (isfloat (x))
+          m = NaN ([1, szx(2 : end)]);
         else
+          m = zeros ([1, szx(2 : end)], outtype);
+        endif
+
+        if (! mod (n, 2))
           ## Even
-          m(1, :) = (x(k, :) + x(k + 1, :)) / 2;
+          if (any (isa(x, "integer")))
+            ## avoid int overflow issues
+
+            ## Use flattened index to simplify N-D operations
+            m(1,:) = x(k, :);
+            m2 = x(k+1, :);
+
+            samesign = prod (sign ([m(1,:); m2]), 1) == 1;
+            m(1,:) = samesign .* m(1,:) + ...
+                       (m2 + !samesign .* m(1,:) - samesign .* m(1,:)) / 2;
+
+          else
+            m(nanfree) = (x(k, nanfree) + x(k+1, nanfree)) / 2;
+          endif
+        else
+          ## Odd. Use flattened index to simplify n-D operations
+          m(nanfree) = x(k, nanfree);
         endif
       endif
-      if (any (hasnan(:)))
-        m(hasnan) = NaN;
-      endif
-    else
-      m = NaN (sz_out);
     endif
   endif
 
   if (perm_flag)
     ## Inverse permute back to correct dimensions
-    m = ipermute (m, perm_vect);
+    m = ipermute (m, perm);
   endif
 
   ## Convert output type as requested
   if (! strcmp (class (m), outtype))
-    m = outtype_convert (m, outtype);
+    m = feval (outtype, m);
   endif
 
 endfunction
 
-function m = outtype_convert (m, outtype)
-  switch (outtype)
-    case "single"
-      m = single (m);
-    case "double"
-      m = double (m);
-    otherwise
-      m = cast (m, outtype);
-  endswitch
-endfunction
-
 %!assert (median (1), 1)
 %!assert (median ([1,2,3]), 2)
 %!assert (median ([1,2,3]'), 2)
@@ -481,7 +506,7 @@ endfunction
 %!assert (median (cat (3, 3, 1, NaN, 2), "omitnan"), 2)
 %!assert (median (cat (3, 3, 1, NaN, 2), 3, "omitnan"), 2)
 
-# Test boolean input
+## Test boolean input
 %!test
 %! assert (median (true, "all"), logical (1));
 %! assert (median (false), logical (0));
@@ -503,11 +528,11 @@ endfunction
 %! assert (size (median (x, [1 2 3 4])), [1 1]);
 
 ## Test exceeding dimensions
-%!assert (median (ones (2,2), 3), ones (2,2));
-%!assert (median (ones (2,2,2), 99), ones (2,2,2));
-%!assert (median (magic (3), 3), magic (3));
-%!assert (median (magic (3), [1 3]), [4, 5, 6]);
-%!assert (median (magic (3), [1 99]), [4, 5, 6]);
+%!assert (median (ones (2,2), 3), ones (2,2))
+%!assert (median (ones (2,2,2), 99), ones (2,2,2))
+%!assert (median (magic (3), 3), magic (3))
+%!assert (median (magic (3), [1 3]), [4, 5, 6])
+%!assert (median (magic (3), [1 99]), [4, 5, 6])
 
 ## Test results with vecdim in n-dimensional arrays and "omitnan"
 %!test
@@ -537,6 +562,7 @@ endfunction
 %!assert (median ([1 2 NaN 3]), NaN)
 %!assert (median ([1 2 NaN 3], "omitnan"), 2)
 %!assert (median ([1,2,NaN;4,5,6;NaN,8,9]), [NaN, 5, NaN])
+%!assert <*64011> (median ([1,2,NaN;4,5,6;NaN,8,9], "omitnan"), [2.5, 5, 7.5], eps)
 %!assert (median ([1 2 ; NaN 4]), [NaN 3])
 %!assert (median ([1 2 ; NaN 4], "omitnan"), [1 3])
 %!assert (median ([1 2 ; NaN 4], 1, "omitnan"), [1 3])
@@ -546,41 +572,79 @@ endfunction
 %!assert (median ([NaN 2 ; NaN 4], "omitnan"), [NaN 3])
 %!assert (median (ones (1, 0, 3)), NaN (1, 1, 3))
 
-%!assert (median (NaN("single")), NaN("single"));
-%!assert (median (NaN("single"), "omitnan"), NaN("single"));
-%!assert (median (NaN("single"), "double"), NaN("double"));
-%!assert (median (single([1 2 ; NaN 4])), single([NaN 3]));
-%!assert (median (single([1 2 ; NaN 4]), "double"), double([NaN 3]));
-%!assert (median (single([1 2 ; NaN 4]), "omitnan"), single([1 3]));
-%!assert (median (single([1 2 ; NaN 4]), "omitnan", "double"), double([1 3]));
-%!assert (median (single([NaN 2 ; NaN 4]), "double"), double([NaN 3]));
-%!assert (median (single([NaN 2 ; NaN 4]), "omitnan"), single([NaN 3]));
-%!assert (median (single([NaN 2 ; NaN 4]), "omitnan", "double"), double([NaN 3]));
+## Test all NaN vectors and arrays - see bug #65405
+%!assert <*65405> (median ([NaN NaN], 1, "omitnan"), [NaN NaN])
+%!assert <*65405> (median ([NaN NaN], 2, "omitnan"), NaN)
+%!assert <*65405> (median ([NaN NaN]', 1, "omitnan"), NaN)
+%!assert <*65405> (median ([NaN NaN]', 2, "omitnan"), [NaN; NaN])
+%!assert <*65405> (median ([NaN NaN], "omitnan"), NaN)
+%!assert <*65405> (median ([NaN NaN]', "omitnan"), NaN)
+%!assert <*65405> (median (NaN(1,9), 1, "omitnan"), NaN(1,9))
+%!assert <*65405> (median (NaN(1,9), 2, "omitnan"), NaN)
+%!assert <*65405> (median (NaN(1,9), 3, "omitnan"), NaN(1,9))
+%!assert <*65405> (median (NaN(9,1), 1, "omitnan"), NaN)
+%!assert <*65405> (median (NaN(9,1), 2, "omitnan"), NaN(9,1))
+%!assert <*65405> (median (NaN(9,1), 3, "omitnan"), NaN(9,1))
+%!assert <*65405> (median (NaN(9,2), 1, "omitnan"), NaN(1,2))
+%!assert <*65405> (median (NaN(9,2), 2, "omitnan"), NaN(9,1))
+%!assert <*65405> (median (NaN(9,2), "omitnan"), NaN(1,2))
 
-%!assert (median (Inf), Inf);
-%!assert (median (-Inf), -Inf);
-%!assert (median ([-Inf Inf]), NaN);
-%!assert (median ([3 Inf]), Inf);
-%!assert (median ([3 4 Inf]), 4);
-%!assert (median ([Inf 3 4]), 4);
-%!assert (median ([Inf 3 Inf]), Inf);
+## Test single inputs
+%!assert (median (NaN("single")), NaN("single"))
+%!assert (median (NaN("single"), "omitnan"), NaN("single"))
+%!assert (median (NaN("single"), "double"), NaN("double"))
+%!assert (median (single([1 2 ; NaN 4])), single([NaN 3]))
+%!assert (median (single([1 2 ; NaN 4]), "double"), double([NaN 3]))
+%!assert (median (single([1 2 ; NaN 4]), "omitnan"), single([1 3]))
+%!assert (median (single([1 2 ; NaN 4]), "omitnan", "double"), double([1 3]))
+%!assert (median (single([NaN 2 ; NaN 4]), "double"), double([NaN 3]))
+%!assert (median (single([NaN 2 ; NaN 4]), "omitnan"), single([NaN 3]))
+%!assert (median (single([NaN 2 ; NaN 4]), "omitnan", "double"), double([NaN 3]))
 
-%!assert (median ([]), NaN);
-%!assert (median (ones(1,0)), NaN);
-%!assert (median (ones(0,1)), NaN);
-%!assert (median ([], 1), NaN(1,0));
-%!assert (median ([], 2), NaN(0,1));
-%!assert (median ([], 3), NaN(0,0));
-%!assert (median (ones(1,0), 1), NaN(1,0));
-%!assert (median (ones(1,0), 2), NaN(1,1));
-%!assert (median (ones(1,0), 3), NaN(1,0));
-%!assert (median (ones(0,1), 1), NaN(1,1));
-%!assert (median (ones(0,1), 2), NaN(0,1));
-%!assert (median (ones(0,1), 3), NaN(0,1));
-%!assert (median (ones(0,1,0,1), 1), NaN(1,1,0));
-%!assert (median (ones(0,1,0,1), 2), NaN(0,1,0));
-%!assert (median (ones(0,1,0,1), 3), NaN(0,1,1));
-%!assert (median (ones(0,1,0,1), 4), NaN(0,1,0));
+## Test omitnan with 2D & 3D inputs to confirm correct sub2ind orientation
+%!test <*64011>
+%! x = [magic(3), magic(3)];
+%! x([3, 7, 11, 12, 16, 17]) = NaN;
+%! ynan = [NaN, 5, NaN, NaN, 5, NaN];
+%! yomitnan = [5.5, 5, 4.5, 8, 5, 2];
+%! assert (median (x), ynan);
+%! assert (median (x, "omitnan"), yomitnan, eps);
+%! assert (median (cat (3, x, x)), cat (3, ynan, ynan));
+%! assert (median (cat (3, x, x), "omitnan"), cat (3, yomitnan, yomitnan), eps);
+
+%!assert (median (Inf), Inf)
+%!assert (median (-Inf), -Inf)
+%!assert (median ([-Inf Inf]), NaN)
+%!assert (median ([3 Inf]), Inf)
+%!assert (median ([3 4 Inf]), 4)
+%!assert (median ([Inf 3 4]), 4)
+%!assert (median ([Inf 3 Inf]), Inf)
+
+%!assert (median ([1, 2, Inf]), 2)
+%!assert (median ([1, 2, Inf, Inf]), Inf)
+%!assert (median ([1, -Inf, Inf, Inf]), Inf)
+%!assert (median ([-Inf, -Inf, Inf, Inf]), NaN)
+%!assert (median([-Inf, Inf, Inf, Inf]), Inf)
+%!assert (median([-Inf, -Inf, -Inf, Inf]), -Inf)
+%!assert (median([-Inf, -Inf, -Inf, 2]), -Inf)
+%!assert (median([-Inf, -Inf, 1, 2]), -Inf)
+
+%!assert (median ([]), NaN)
+%!assert (median (ones(1,0)), NaN)
+%!assert (median (ones(0,1)), NaN)
+%!assert (median ([], 1), NaN(1,0))
+%!assert (median ([], 2), NaN(0,1))
+%!assert (median ([], 3), NaN(0,0))
+%!assert (median (ones(1,0), 1), NaN(1,0))
+%!assert (median (ones(1,0), 2), NaN(1,1))
+%!assert (median (ones(1,0), 3), NaN(1,0))
+%!assert (median (ones(0,1), 1), NaN(1,1))
+%!assert (median (ones(0,1), 2), NaN(0,1))
+%!assert (median (ones(0,1), 3), NaN(0,1))
+%!assert (median (ones(0,1,0,1), 1), NaN(1,1,0))
+%!assert (median (ones(0,1,0,1), 2), NaN(0,1,0))
+%!assert (median (ones(0,1,0,1), 3), NaN(0,1,1))
+%!assert (median (ones(0,1,0,1), 4), NaN(0,1,0))
 
 ## Test complex inputs (should sort by abs(a))
 %!assert (median([1 3 3i 2 1i]), 2)
@@ -599,6 +663,12 @@ endfunction
 %!assert <*35679> (median (b, 3), (y(:, :, 3, :) + y(:, :, 4, :))/2)
 %!shared   ## Clear shared to prevent variable echo for any later test failures
 
+## Test n-dimensional arrays with odd non-NaN data points
+%!test
+%! x = ones(15,1,4);
+%! x([13,15],1,:) = NaN;
+%! assert (median (x, 1, "omitnan"), ones (1,1,4))
+
 ## Test non-floating point types
 %!assert (median ([true, false]), true)
 %!assert (median (logical ([])), false)
@@ -610,10 +680,52 @@ endfunction
 %!assert (median (single ([1, 3, 4])), single (3))
 %!assert (median (single ([1, 3, NaN])), single (NaN))
 
+## Test same sign int overflow when getting mean of even number of values
+%!assert <54567> (median (uint8 ([253, 255])), uint8 (254))
+%!assert <54567> (median (uint8 ([253, 254])), uint8 (254))
+%!assert <54567> (median (int8 ([127, 126, 125, 124; 1 3 5 9])), ...
+%!                  int8 ([64 65 65 67]))
+%!assert <54567> (median (int8 ([127, 126, 125, 124; 1 3 5 9]), 2), ...
+%!                  int8 ([126; 4]))
+%!assert <54567> (median (int64 ([intmax("int64"), intmax("int64")-2])), ...
+%!                  intmax ("int64") - 1)
+%!assert <54567> (median ( ...
+%!                 int64 ([intmax("int64"), intmax("int64")-2; 1 2]), 2), ...
+%!                 int64([intmax("int64") - 1; 2]))
+%!assert <54567> (median (uint64 ([intmax("uint64"), intmax("uint64")-2])), ...
+%!                  intmax ("uint64") - 1)
+%!assert <54567> (median ( ...
+%!                 uint64 ([intmax("uint64"), intmax("uint64")-2; 1 2]), 2), ...
+%!                 uint64([intmax("uint64") - 1; 2]))
+
+## Test opposite sign int overflow when getting mean of even number of values
+%!assert <54567> (median (...
+%! [intmin('int8') intmin('int8')+5 intmax('int8')-5 intmax('int8')]), ...
+%! int8(-1))
+%!assert <54567> (median ([int8([1 2 3 4]); ...
+%! intmin('int8') intmin('int8')+5 intmax('int8')-5 intmax('int8')], 2), ...
+%! int8([3;-1]))
+%!assert <54567> (median (...
+%! [intmin('int64') intmin('int64')+5 intmax('int64')-5 intmax('int64')]), ...
+%! int64(-1))
+%!assert <54567> (median ([int64([1 2 3 4]); ...
+%! intmin('int64') intmin('int64')+5 intmax('int64')-5 intmax('int64')], 2), ...
+%! int64([3;-1]))
+
+## Test int accuracy loss doing mean of close int64/uint64 values as double
+%!assert <54567> (median ([intmax("uint64"), intmax("uint64")-2]), ...
+%!  intmax("uint64")-1)
+%!assert <54567> (median ([intmax("uint64"), intmax("uint64")-2], "default"), ...
+%!  double(intmax("uint64")-1))
+%!assert <54567> (median ([intmax("uint64"), intmax("uint64")-2], "double"), ...
+%!  double(intmax("uint64")-1))
+%!assert <54567> (median ([intmax("uint64"), intmax("uint64")-2], "native"), ...
+%!  intmax("uint64")-1)
+
 ## Test input case insensitivity
-%!assert (median ([1 2 3], "aLL"), 2);
-%!assert (median ([1 2 3], "OmitNan"), 2);
-%!assert (median ([1 2 3], "DOUBle"), 2);
+%!assert (median ([1 2 3], "aLL"), 2)
+%!assert (median ([1 2 3], "OmitNan"), 2)
+%!assert (median ([1 2 3], "DOUBle"), 2)
 
 ## Test input validation
 %!error <Invalid call> median ()
